/*
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved.
 *
 * Author: TCSDEVELOPER, TCSDESIGNER
 * Version: 1.0
 */

using System;
using System.Reflection;
using NUnit.Framework;
using System.IO;
using System.Collections;
using System.Text.RegularExpressions;

namespace TopCoder.File.Statistics.Matcher
{
    /// <summary>
    /// Tests the <c>MimeMatcher</c> class, by verifying a few test file names and different configurations.
    /// </summary>
    [TestFixture]
    public class TestMimeMatcher : TestFileMatcher
    {
        /// <summary>
        /// A few regex matchers used in testing, based on configuration and programmatical constructors.
        /// </summary>
        IFileMatcher[] matchers = new IFileMatcher[4];

        /// <summary>
        /// Publishes some information to base classes.
        /// </summary>
        [SetUp]
        public void Setup()
        {
            type = typeof(MimeMatcher);
            instance = new MimeMatcher("application/java");
            matchers[0] = instance;
            IList list = new ArrayList();
            list.Add("application/x-ms-dos-executable");
            list.Add("application/java");
            matchers[1] = new MimeMatcher(list);
            matchers[2] = new MimeMatcher("TopCoder.File.Statistics", "1");
            matchers[3] = new MimeMatcher("TopCoder.File.Statistics", "2");
        }

        /// <summary>
        /// The list is present, but empty.
        /// </summary>
        [ExpectedException(typeof(ConfigurationException))]
        public void TestInvalidConfig1()
        {
            Constructor("TopCoder.File.Statistics", "3");
        }

        /// <summary>
        /// The list isn't present.
        /// </summary>
        [ExpectedException(typeof(ConfigurationException))]
        public void TestInvalidConfig2()
        {
            Constructor("TopCoder.File.Statistics", "4");
        }

        /// <summary>
        /// A list element is empty.
        /// </summary>
        [ExpectedException(typeof(ConfigurationException))]
        public void TestInvalidConfig3()
        {
            Constructor("TopCoder.File.Statistics", "5");
        }

        /// <summary>
        /// Tests matching of arbitrary <c>FileInfo</c> instances.
        /// </summary>
        [Test]
        public void TestMatch()
        {
            for (int i = 0; i < 4; i += 3)
            {
                Assert.IsTrue(matchers[i].Match(new FileInfo(@"..\..\test_files\AllTests.class")),
                    "Java file should match matcher " + i);
                Assert.IsFalse(matchers[i].Match(new FileInfo(@"..\..\test_files\test.xml")),
                    "XML file shouldn't match matcher " + i);
                Assert.IsFalse(matchers[i].Match(new FileInfo(@"..\..\test_files\test.exe")),
                    "Exe file shouldn't match matcher " + i);
            }

            for (int i = 1; i < 3; i++)
            {
                Assert.IsTrue(matchers[i].Match(new FileInfo(@"..\..\test_files\AllTests.class")),
                    "Java file should match matcher " + i);
                Assert.IsFalse(matchers[i].Match(new FileInfo(@"..\..\test_files\test.xml")),
                    "XML file shouldn't match matcher " + i);
                Assert.IsTrue(matchers[i].Match(new FileInfo(@"..\..\test_files\test.exe")),
                    "Exe file should match matcher " + i);
            }
        }
    }
}