/*
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved.
 *
 * Author: TCSDEVELOPER, TCSDESIGNER
 * Version: 1.0
 */

using System;
using System.Reflection;
using TopCoder.Util.ConfigurationManager;
using NUnit.Framework;
using System.IO;

namespace TopCoder.File.Statistics.Processor.LineCounter
{
    /// <summary>
    /// This class is a base for verifying basic functionality of <c>FileProcessorBase</c> implementations, based on
    /// <c>TestContract</c>.
    /// </summary>
    [TestFixture]
    public class TestCStyleLineCounter : TestFileProcessorBare
    {
        /// <summary>
        /// Sets up the processors used in testing.
        /// </summary>
        [SetUp]
        public override void Setup()
        {
            type = typeof(CStyleLineCounter);
            base.Setup();
        }

        /// <summary>
        /// Tests the direct (alias, matcher) constructor with null parameters.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void TestNullDirectConstructor2()
        {
            new CStyleLineCounter("alias", (IFileMatcher) null);
        }

        /// <summary>
        /// Tests null parameters for the contract constructor. Overriden due to ambiguity.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public override void TestContractConstructorNull2()
        {
            new CStyleLineCounter("namespace", (string) null);
        }

        /// <summary>
        /// A short helper extracting the lines from processing.
        /// </summary>
        /// <param name="filename">The filename.</param>
        /// <returns>The resulting number of lines.</returns>
        public long CountLines(string filename)
        {
            StatsResult res = procs[0].Process(new FileInfo(filename));
            return res[(Metric) procs[0].SupportedMetrics[0]];
        }

        /// <summary>
        /// Tests the processing method for a few text files, comparing against precomputed correct values.
        /// </summary>
        [Test]
        public void TestProcess()
        {
            Assert.AreEqual(5, CountLines(@"..\..\test_files\TestFile1.cs"), "TestFile1.cs");
            Assert.AreEqual(2, CountLines(@"..\..\test_files\TestFile2.cs"), "TestFile2.cs");
        }
    }
}