/*
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved.
 *
 * Author: TCSDEVELOPER, TCSDESIGNER
 * Version: 1.0
 */

using System;
using System.IO;
using System.Reflection;
using TopCoder.Util.ConfigurationManager;
using NUnit.Framework;

namespace TopCoder.File.Statistics
{
    /// <summary>
    /// This class tests the operation of <c>FileStatistics</c>, mainly based on the assumption that the underlying
    /// classes, which are tested through other, individual, tests, work properly.
    /// </summary>
    [TestFixture]
    public class TestExtendedFileStatistics : TestFileStatistics
    {
        /// <summary>
        /// The report template.
        /// </summary>
        private const string report = @"File statistics report

Overall results:
    No statistic data available for this item.


";

        /// <summary>
        /// Sets up the testing instances.
        /// </summary>
        [SetUp]
        public override void Setup()
        {
            type = typeof(ExtendedFileStatistics);
            base.Setup();
        }

        /// <summary>
        /// Processes a directory non-recursively.
        /// </summary>
        [Test]
        public void TestNonRecursive1()
        {
            ((ExtendedFileStatistics) instances[1]).ProcessDirectory(new DirectoryInfo(@"..\..\test_files\sub"));
            Assert.AreEqual(2, ((Reporting.AbstractStatsReporting) instances[1].Reporting).FileStats.AllKeys.Count,
                "Exactly two files should be processed.");
        }

        /// <summary>
        /// Processes a directory non-recursively.
        /// </summary>
        [Test]
        public void TestNonRecursive2()
        {
            ((ExtendedFileStatistics) instances[1]).ProcessDirectory(new DirectoryInfo(@"..\..\test_files\sub"),
                false);
            Assert.AreEqual(2, ((Reporting.AbstractStatsReporting) instances[1].Reporting).FileStats.AllKeys.Count,
                "Exactly two files should be processed.");
        }

        /// <summary>
        /// Processes a directory non-recursively.
        /// </summary>
        [Test]
        public void TestRecursive()
        {
            ((ExtendedFileStatistics) instances[1]).ProcessDirectory(new DirectoryInfo(@"..\..\test_files\sub"), true);
            Assert.AreEqual(3, ((Reporting.AbstractStatsReporting) instances[1].Reporting).FileStats.AllKeys.Count,
                "Exactly three files should be processed.");
        }

        /// <summary>
        /// Tests processing a null directory.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void TestNull()
        {
            ((ExtendedFileStatistics) instances[1]).ProcessDirectory(null, true);
        }

        /// <summary>
        /// Tests printing a report with a null filename.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void TestPrintReportNull()
        {
            ((ExtendedFileStatistics) instances[1]).PrintReport(null);
        }

        /// <summary>
        /// Tests printing a report to a file.
        /// </summary>
        [Test]
        public void TestPrintReport()
        {
            FileInfo file = new FileInfo(@"..\..\test_files\report.txt");
            try
            {
                ((ExtendedFileStatistics) instances[1]).PrintReport(file);
                using (TextReader reader = file.OpenText())
                {
                    Assert.AreEqual(report, reader.ReadToEnd(), "Report should match.");
                }
            }
            finally
            {
                file.Delete();
            }
        }
    }
}