/*
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved.
 *
 * Author: TCSDEVELOPER, TCSDESIGNER
 * Version: 2.0b
 */


using System;
using System.Collections;
using System.IO;

namespace TopCoder.File.Statistics
{
    /// <summary>
    /// The <c>IStatsReporting</c> interface defines the contract to aggregate and render the statistical report.
    /// The results are fed into this interface one by one and the file report is then generated. There is a way to
    /// reset (clear) the current aggregated results.
    /// </summary>
    /// <remarks>
    /// Every implementation should have a constructor with two string arguments, for namespace and property name
    /// prefixa in order to reflect from the configuration file. This requirement can be dropped if the reporting
    /// mechanism will never be used in this way.
    ///
    /// There is no requirement or recommendation regarding thread safety for implementations
    /// </remarks>
    public interface IStatsReporting
    {
        /// <summary>
        /// Aggregates, adds, a new result to the ones already reported.
        /// </summary>
        /// <param name="processor">The processor used for this result.</param>
        /// <param name="file">The file the results apply to.</param>
        /// <param name="result">The result to aggregate.</param>
        /// <exception cref="ArgumentNullException">If any argument is null.</exception>
        /// <exception cref="StatsReportingException">If the file is not present in the directory tree to the
        /// specified base dir.</exception>
        void Aggregate(IFileProcessor processor, FileInfo file, StatsResult result);

        /// <summary>
        /// Generate the report with all the aggregated results.
        /// </summary>
        /// <exception cref="StatsReportingException">If any error occurs.</exception>
        /// <returns>The generated report.</returns>
        string GenerateReport();

        /// <summary>
        /// Clear all the aggregated result and set the base dir (which is nullable).
        /// </summary>
        /// <param name="baseDirectory">The base dir to reset.</param>
        /// <exception cref="ArgumentException">If a non-existing base directory is specified.</exception>
        void Reset(DirectoryInfo baseDirectory);
    }
}