/*
Copyright (c)2005, TopCoder, Inc. All rights reserved
Author Cucu
*/

using NUnit.Framework;
using TopCoder.File.Statistics;
using System.IO;
using System.Collections;
using TopCoder.Util.ConfigurationManager;
using System.Text.RegularExpressions;
using TopCoder.File.Statistics.AccuracyTests;
using TopCoder.File.Statistics.Matcher;

namespace TopCoder.File.Statistics.AccuracyTests.Matcher
{
    /// <summary>
    /// </summary>
    [TestFixture]
    public class MimeMatcherAccuracyTest
    {              
        /// <summary>
        /// Set up for each test.
        /// </summary>
        [SetUp]
        public void SetUp()
        {
            TestHelper.LoadConfig(TestHelper.MAGIC_NUMBERS_CONFIG);
            TestHelper.LoadConfig(TestHelper.MATCHERS_CONFIG);
        }

        /// <summary>
        /// Tear down for each test.
        /// </summary>
        [TearDown]
        public void Teardown()
        {
            TestHelper.UnloadConfig(TestHelper.MATCHERS_CONFIG);
            TestHelper.UnloadConfig(TestHelper.MAGIC_NUMBERS_CONFIG);
        }

        /// <summary>
        /// Test the Match method against a single type
        /// </summary>
        [Test]
        public void MatchWithStringConstructor()
        {
            IFileMatcher matcher = new MimeMatcher(@"binary/zip");
            
            Assert.IsTrue(matcher.Match(new FileInfo(TestHelper.ZIP_FILE)),
                TestHelper.ZIP_FILE + " should match against 'binary/zip' mime");

            Assert.IsFalse(matcher.Match(new FileInfo(TestHelper.TXT_FILE)),
                TestHelper.TXT_FILE + " should NOT match against 'binary/zip' mime");

            Assert.IsFalse(matcher.Match(new FileInfo(TestHelper.CS_FILE)),
                TestHelper.CS_FILE + " should NOT match against 'binary/zip' mime");
            
            Assert.IsFalse(matcher.Match(new FileInfo(TestHelper.DLL_FILE)),
                TestHelper.DLL_FILE + " should NOT match against 'binary/zip' mime");

        }

        /// <summary>
        /// Test that the list constructor makes a copy of the list
        /// </summary>
        [Test]
        public void TestListConstructor() 
        {
            IList mimes  = new ArrayList();
            mimes.Add(@"binary/zip");
            
            IFileMatcher matcher = new TypeNameMatcher(mimes);
            
            // this shouldn't affect the matcher
            mimes.Add(@"application/x-ms-dos-executable");
            
            Assert.IsFalse(matcher.Match(new FileInfo(TestHelper.DLL_FILE)), "constructor is not making a copy");
        }

        
        /// <summary>
        /// Test the Match method against many patterns, using the constructor that takes a list of extensions.
        /// </summary>
        [Test]
        public void MatchWithListConstructor()
        {
            IList mimes = new ArrayList();
            mimes.Add(@"binary/zip");
            mimes.Add(@"application/x-ms-dos-executable");
            
            IFileMatcher matcher = new MimeMatcher(mimes);

            checkMimes(matcher);
        }

        /// <summary>
        /// Test the Match method against many extensions, using the constructor that reads from the configuration file.
        /// </summary>
        [Test]
        public void MatchWitConfigManagerConstructor()
        {
            IFileMatcher matcher = new MimeMatcher(TestHelper.FILE_STATISTICS_NAMESPACE, "mime.matcher.");
            checkMimes(matcher);
        }

        /// <summary>
        /// Check that the matcher passed is matching well with the types: ZIP file and Windows executable
        /// </summary>
        /// <param name="matcher">the matcher to check.</param>
        private void checkMimes(IFileMatcher matcher) {
            Assert.IsTrue(matcher.Match(new FileInfo(TestHelper.ZIP_FILE)),
                TestHelper.ZIP_FILE + " should match against mime list");

            Assert.IsTrue(matcher.Match(new FileInfo(TestHelper.DLL_FILE)),
                TestHelper.DLL_FILE + " should match against mime list");

            Assert.IsFalse(matcher.Match(new FileInfo(TestHelper.TXT_FILE)),
                TestHelper.TXT_FILE + " should NOT match against mime list");

            Assert.IsFalse(matcher.Match(new FileInfo(TestHelper.CS_FILE)),
                TestHelper.CS_FILE + " should NOT match against mime list");
            

        }

         }    
}