/*
Copyright (c)2005, TopCoder, Inc. All rights reserved
Author Cucu
*/
using TopCoder.File.Statistics.Matcher;
using TopCoder.File.Statistics.Reporting;
using TopCoder.File.Statistics.Processor.LineCounter;
using NUnit.Framework;
using TopCoder.File.Statistics;
using System.IO;

namespace TopCoder.File.Statistics.AccuracyTests.Reporting
{
    /// <summary>
    /// Accuracy tests for BasicStatsReporting
    /// </summary>
    [TestFixture]
    public class BasicStatsReportingAccuracyTest
    {       
        /// <summary>
        /// Test creating an empty report and saving it so it can be visually inspected.
        /// </summary>
        [Test]
        public void TestEmptyReport()
        {
            BasicStatsReporting bsr = new BasicStatsReporting();
            CreateReport(bsr, new string[]{},@"..\..\test_files\AccuracyTests\ReportResults\EmptyReport.txt");
        }

        /// <summary>
        /// Test creating a report of a file and saving it so it can be visually inspected.
        /// </summary>
        [Test]
        public void TestReport1()
        {
            BasicStatsReporting bsr = new BasicStatsReporting();
            CreateReport(bsr, new string[]{TestHelper.CS_FILE},@"..\..\test_files\AccuracyTests\ReportResults\Report1.txt");
        }

        /// <summary>
        /// Test creating a report of some files and saving it so it can be visually inspected.
        /// </summary>
        [Test]
        public void TestReport2()
        {
            BasicStatsReporting bsr = new BasicStatsReporting();
            CreateReport(bsr, new string[]{TestHelper.CS_FILE, TestHelper.JAVA_FILE, TestHelper.CPP_FILE, TestHelper.CPP_FILE_ANOTHER_DIR}
                    ,@"..\..\test_files\AccuracyTests\ReportResults\Report2.txt");
        }

        /// <summary>
        /// Test doing a reset to have a base directory.
        /// </summary>
        [Test]
        public void TestReset()
        {
            BasicStatsReporting bsr = new BasicStatsReporting();
            bsr.Reset(new DirectoryInfo(@"..\..\test_files\AccuracyTests\files\"));

            CreateReport(bsr, new string[]{TestHelper.CS_FILE, TestHelper.JAVA_FILE, TestHelper.CPP_FILE, TestHelper.CPP_FILE_ANOTHER_DIR},
                @"..\..\test_files\AccuracyTests\ReportResults\Reset.txt");
        }

        /// <summary>
        /// Creata a report with BasicStatsReporting and outputs it to a file
        /// </summary>
        /// <param name="files">files to be processed</param>
        /// <param name="outputFileName">name of the file where the report is written</param>
        private void CreateReport(BasicStatsReporting bsr, string []files, string outputFileName) 
        {
            
            IFileProcessor fp = new CStyleLineCounter("Source File", new AnyFileMatcher());

            foreach (string filename in files) 
            {
                StatsResult sr = new StatsResult();
                FileInfo fi = new FileInfo(filename);
                sr.Aggregate(fp.Process(fi));
                bsr.Aggregate(fp, fi, sr);
            }

            StreamWriter sw = new StreamWriter(outputFileName);
            sw.Write(bsr.GenerateReport());
            sw.Close();
        }

    }    
}