/*
 * $(#)FileStatisticsTests.java		Sep 6, 2005
 * 
 * Copyright (c) 2005, TopCoder Inc. All rights reserved.
 */

using System;
using System.IO;
using NUnit.Framework;

using TopCoder.File.Statistics;
using TopCoder.Util.ConfigurationManager;

namespace TopCoder.File.Statistics.FailureTests {
	
	/// <summary>
    /// This test fixture contains the failure tests for <see cref="FileStatistics"/> class.
    ///
    /// <author>MPhk</author>
    /// <version>1.0</version>
    /// <copyright>Copyright (C) 2005 TopCoder Inc., All Rights Reserved.</copyright>
    /// </summary>
    [TestFixture]
	public class FileStatisticsTests {

    	/// <summary>
	    /// The the base path of the test files.
	    /// </summary>
	    private const string BASE_PATH = "../../test_files";
	    
	    /// <summary>
	    /// The namespace for this test.
	    /// </summary>
	    private const string NAMESPACE = "TopCoder.File.Statistics.FailureTests";
	
	    /// <summary>
	    /// An FileStatistics instance to test.
	    /// </summary>
	    private FileStatistics fileStatistics = null;
	
	    /// <summary>
	    /// Creates an FileStatistics instance.
	    ///
	    /// @throws Exception in case anything goes wrong
	    /// </summary>
	    [SetUp]
	    protected void SetUp() {
	        fileStatistics = new FileStatistics();
	    }
	
	    /// <summary>
	    /// Checks whether the constructor - FileStatistics(String) properly throws
	    /// ArgumentNullException for null argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentNullException))]
	    public void TestFileStatistics1() {
	        new FileStatistics(null);
	    }
	
	    /// <summary>
	    /// Checks whether the constructor - FileStatistics(String) properly throws
	    /// ArgumentException for empty String argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentException))]
	    public void TestFileStatistics2() {
	        new FileStatistics(" ");
	    }
	
	    /// <summary>
	    /// Checks whether the constructor - FileStatistics(String) properly throws
	    /// ConfigurationException for invalid configuration.
	    /// </summary>
	    [Test, ExpectedException(typeof(ConfigurationException))]
	    public void TestFileStatistics3() {
	        const string CONFIG_FILE_1 = BASE_PATH + "/failuretests/invalid1.xml";
	        const string CONFIG_FILE_2 = BASE_PATH + "/failuretests/invalid2.xml";
	        // clear the namespace first
	        ConfigManager configManager = ConfigManager.GetInstance();
	        configManager.RemoveFile(CONFIG_FILE_1);
	        configManager.RemoveFile(CONFIG_FILE_2);
	        // load the configuration
	        configManager.LoadFile(CONFIG_FILE_1);
	
	        new FileStatistics(NAMESPACE);
            configManager.RemoveFile(NAMESPACE);
	    }
	
	    /// <summary>
	    /// Checks whether the constructor - FileStatistics(String) properly throws
	    /// ConfigurationException for invalid configuration.
	    /// </summary>
	    [Test, ExpectedException(typeof(ConfigurationException))]
	    public void TestFileStatistics4() {
	        const string CONFIG_FILE_1 = BASE_PATH + "/failuretests/invalid1.xml";
	        const string CONFIG_FILE_2 = BASE_PATH + "/failuretests/invalid2.xml";
	        // clear the namespace first
	        ConfigManager configManager = ConfigManager.GetInstance();
	        configManager.RemoveFile(CONFIG_FILE_1);
	        configManager.RemoveFile(CONFIG_FILE_2);
	        // load the configuration
	        configManager.LoadFile(CONFIG_FILE_2);
	
	        new FileStatistics(NAMESPACE);
            configManager.RemoveFile(NAMESPACE);
	    }
	
	    /// <summary>
	    /// Checks whether the method addFileProcessor(String) properly throws
	    /// ArgumentNullException for null argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentNullException))]
	    public void TestAddFileProcessor() {
            fileStatistics.AddFileProcessor(null);
	    }
	
	    /// <summary>
	    /// Checks whether the method removeFileProcessor(String) properly throws
	    /// ArgumentNullException for null argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentNullException))]
	    public void TestRemoveFileProcessor1() {
            fileStatistics.RemoveFileProcessor(null);
	    }
	
	    /// <summary>
	    /// Checks whether the method removeFileProcessor(String) properly throws
	    /// ArgumentException for empty String argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentException))]
	    public void TestRemoveFileProcessor2() {
            fileStatistics.RemoveFileProcessor(" ");
	    }
	    
	    /// <summary>
	    /// Checks whether the method setReporting(StatsReporting) properly throws
	    /// ArgumentNullException for null argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentNullException))]
	    public void TestSetReporting() {
            fileStatistics.Reporting = null;
	    }
	
	    /// <summary>
	    /// Checks whether the method processFile(DirectoryInfo) properly throws
	    /// ArgumentNullException for null argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentNullException))]
	    public void TestProccessFile() {
            fileStatistics.ProcessFile(null);
	    }
	}
}
