///
/// $(#)TextFileMatcherTests.cs		Sep 6, 2005
/// 
/// Copyright (c) 2005, TopCoder Inc. All rights reserved.
/// </summary>

using System;
using System.IO;
using NUnit.Framework;

using TopCoder.File.Statistics.Matcher;

namespace TopCoder.File.Statistics.FailureTests.Matcher
{
	/// <summary>
    /// This test fixture contains the failure tests for <see cref="TextFileMatcher"/> class.
    ///
    /// <author>MPhk</author>
    /// <version>1.0</version>
    /// <copyright>Copyright (C) 2005 TopCoder Inc., All Rights Reserved.</copyright>
    /// </summary>
    [TestFixture]
	public class TextFileMatcherTests {
	
	    /// <summary>
	    /// The the base path of the test files.
	    /// </summary>
	    private const string BASE_PATH = "../../test_files/failuretests/matcher/";
	    
	    /// <summary>
	    /// Checks whether the constructor TextFileMatcher(string, string) properly throws
	    /// ArgumentNullException for null argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentNullException))]
	    public void TestTextFileMatcher1() {
            new TextFileMatcher(null, "prefix.");
	    }
	    
	    /// <summary>
	    /// Checks whether the constructor TextFileMatcher(string, string) properly throws
	    /// ArgumentException for empty argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentException))]
	    public void TestTextFileMatcher2() {
            new TextFileMatcher("", "prefix.");
	    }
	    
	    /// <summary>
	    /// Checks whether the constructor TextFileMatcher(string, string) properly throws
	    /// ArgumentNullException for null argument.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentNullException))]
	    public void TestTextFileMatcher3() {
            new TextFileMatcher("namespace", null);
	    }
	    
	    /// <summary>
	    /// Tests the match method with null argument. ArgumentNullException should be thrown.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentNullException))]
	    public void TestMatch1() {
            new TextFileMatcher().Match(null);
	    }
	    
	    /// <summary>
	    /// Tests the match method for a file that does not exist. IOException should be thrown.
	    /// </summary>
	    [Test, ExpectedException(typeof(IOException))]
	    public void TestMatch2() {
	    	try {
            	new TextFileMatcher().Match(new FileInfo(BASE_PATH));
            } catch (IOException) {
	    		throw new IOException();
	    	}
	    }
	    
	    /// <summary>
	    /// Tests the isBinary method with null argument. ArgumentNullException should be thrown.
	    /// </summary>
	    [Test, ExpectedException(typeof(ArgumentNullException))]
	    public void TestIsBinary1() {
            TextFileMatcher.IsBinary(null);
	    }
	    
	    /// <summary>
	    /// Tests the isBinary method for a file that does not exist. IOException should be thrown.
	    /// </summary>
	    [Test, ExpectedException(typeof(IOException))]
	    public void TestIsBinary2() {
	    	try {
            	TextFileMatcher.IsBinary(new FileInfo(BASE_PATH + "/inexistent_file"));
            } catch (IOException) {
	    		throw new IOException();
	    	}
	    }
	    
	    /// <summary>
	    /// Tests the isBinary method for a folder. IOException should be thrown.
	    /// </summary>
	    [Test, ExpectedException(typeof(IOException))]
	    public void TestIsBinary3() {
	    	try {
            	TextFileMatcher.IsBinary(new FileInfo(BASE_PATH));
            } catch (IOException) {
	    		throw new IOException();
	    	}
	    }    
	}
}
