/*
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved.
 *
 * Author: TCSDEVELOPER, TCSDESIGNER
 * Version: 2.0b
 */

using System;
using System.Reflection;
using TopCoder.Util.ConfigurationManager;
using NUnit.Framework;

namespace TopCoder.File.Statistics
{
    /// <summary>
    /// This class is a base for verifying error functionality in the contract constructors, that is, the constructors
    /// that take a namespace and a property name prefix.
    /// </summary>
    [TestFixture]
    public abstract class TestContract
    {
        /// <summary>
        /// This field is set in subclasses for proper instantiation.
        /// </summary>
        protected Type type;

        /// <summary>
        /// Sets up the testing fixture.
        /// </summary>
        [TestFixtureSetUp]
        public void FixtureSetup()
        {
            ConfigManager.GetInstance().Clear(false);
            ConfigManager.GetInstance().LoadFile(@"..\..\test_files\test.xml");
        }

        /// <summary>
        /// Invokes the class constructor.
        /// </summary>
        /// <param name="args">The desired constructor parameters.</param>
        /// <returns>
        /// An object.
        /// </returns>
        public object Constructor(params object[] args)
        {
            try
            {
                return Activator.CreateInstance(type, args);
            }
            catch (TargetInvocationException e)
            {
                // Expose the inner exception for normal test fixture operation
                throw e.InnerException;
            }
        }

        /// <summary>
        /// Tests null parameters for the contract constructor.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public virtual void TestContractConstructorNull1()
        {
            Constructor(null, "prefix.");
        }

        /// <summary>
        /// Tests null parameters for the contract constructor.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public virtual void TestContractConstructorNull2()
        {
            Constructor("namespace", null);
        }

        /// <summary>
        /// Tests an empty namespace. The prefix is allowed to be empty.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentException))]
        public void TestContractConstructorEmpty()
        {
            Constructor("  ", "prefix.");
        }

        /// <summary>
        /// Tests a non-existing namespace.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ConfigurationException))]
        public void TestContractConstructorInvalidNamespace()
        {
            Constructor("namespace", "");
        }
    }
}
