/*
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved.
 *
 * Author: TCSDEVELOPER, TCSDESIGNER
 * Version: 2.0b
 */

using System;
using System.Reflection;
using TopCoder.Util.ConfigurationManager;
using NUnit.Framework;

namespace TopCoder.File.Statistics
{
    /// <summary>
    /// This class is a base for verifying error functionality in the exception classes. They are all alike, the only
    /// difference is in the type hierarchy itself.
    /// </summary>
    [TestFixture]
    public abstract class TestFileStatisticsException
    {
        /// <summary>
        /// This field is set in subclasses for proper instantiation.
        /// </summary>
        protected Type type;

        /// <summary>
        /// Invokes the class constructor.
        /// </summary>
        /// <param name="args">The desired constructor parameters.</param>
        public Exception Constructor(params object[] args)
        {
            try
            {
                return (Exception) Activator.CreateInstance(type, args);
            }
            catch (TargetInvocationException e)
            {
                // Expose the inner exception for normal test fixture operation
                throw e.InnerException;
            }
        }

        /// <summary>
        /// Tests the single param constructor.
        /// </summary>
        [Test]
        public void TestSingleParam()
        {
            Exception e = Constructor("msg");
            Assert.AreEqual("msg", e.Message, "The passed in message should match.");
            Assert.IsNull(e.InnerException, "Inner exception should be null.");
        }

        /// <summary>
        /// Tests the two param constructor.
        /// </summary>
        [Test]
        public void TestDualParam()
        {
            Exception inner = new Exception("e");
            Exception e = Constructor("msg", inner);
            Assert.AreEqual("msg", e.Message, "The passed in message should match.");
            Assert.AreEqual(inner, e.InnerException, "Inner exception should match.");
        }
    }

    /// <summary>
    /// Tests the <c>ConfigurationException</c> class.
    /// </summary>
    public class TestConfigurationException : TestFileStatisticsException
    {
        /// <summary>
        /// Set the <c>type</c> variable appropriately.
        /// </summary>
        [SetUp]
        public void Setup()
        {
            type = typeof(ConfigurationException);
        }
    }

    /// <summary>
    /// Tests the <c>FileMatchingException</c> class.
    /// </summary>
    public class TestFileMatchingException : TestFileStatisticsException
    {
        /// <summary>
        /// Set the <c>type</c> variable appropriately.
        /// </summary>
        [SetUp]
        public void Setup()
        {
            type = typeof(FileMatchingException);
        }
    }

    /// <summary>
    /// Tests the <c>FileProcessingException</c> class.
    /// </summary>
    public class TestFileProcessingException : TestFileStatisticsException
    {
        /// <summary>
        /// Set the <c>type</c> variable appropriately.
        /// </summary>
        [SetUp]
        public void Setup()
        {
            type = typeof(FileProcessingException);
        }
    }

    /// <summary>
    /// Tests the <c>StatsReportingException</c> class.
    /// </summary>
    public class TestStatsReportingException : TestFileStatisticsException
    {
        /// <summary>
        /// Set the <c>type</c> variable appropriately.
        /// </summary>
        [SetUp]
        public void Setup()
        {
            type = typeof(StatsReportingException);
        }
    }
    
    /// <summary>
    /// Tests the <c>StatsReportingException</c> class.
    /// </summary>
    public class TestInvalidArgumentException : TestFileStatisticsException
    {
        /// <summary>
        /// Set the <c>type</c> variable appropriately.
        /// </summary>
        [SetUp]
        public void Setup()
        {
            type = typeof(InvalidArgumentException);
        }
    }
    
    /// <summary>
    /// Tests the <c>MissingInitializationException</c> class.
    /// </summary>
    public class TestMissingInitializationException : TestFileStatisticsException
    {
        /// <summary>
        /// Set the <c>type</c> variable appropriately.
        /// </summary>
        [SetUp]
        public void Setup()
        {
            type = typeof(MissingInitializationException);
        }
    }
}
